@@ -1,5 +1,16 @@
-BASE_URL = "http://censius-logs-prod1.us-east-1.elasticbeanstalk.com/v1"
-AMS_URL = "http://ams-prod.us-east-1.elasticbeanstalk.com"
+# BASE_URL = "http://censius-logs-prod1.us-east-1.elasticbeanstalk.com/v1"
+# AMS_URL = "http://ams-prod.us-east-1.elasticbeanstalk.com"
+# MONITORS_PROGRAMMATIC_BASE_URL = (
+#     "http://monitors-prod.us-east-1.elasticbeanstalk.com//v1/programmatic"
+# )
+# BASE_URL = "http://censiuslogs-dev.us-east-1.elasticbeanstalk.com//v1"
+# AMS_URL = "http://ams-dev0.us-east-1.elasticbeanstalk.com"
+# MONITORS_PROGRAMMATIC_BASE_URL = (
+#    "http://monitors-env.eba-ptkdpfrn.us-east-1.elasticbeanstalk.com/v1/programmatic"
+# )
+
+BASE_URL = "https://console.censius.ai/logs-svc/v1"
+AMS_URL = "https://console.censius.ai/ams-svc"
 MONITORS_PROGRAMMATIC_BASE_URL = (
     "http://monitors-prod.us-east-1.elasticbeanstalk.com//v1/programmatic"
 )
@@ -32,3 +43,4 @@ REGISTER_PROJECT_URL = lambda: f"{AMS_URL}/projects/register-project"
 
 # Monitors
 GET_MODEL_HEALTH_URL = lambda: f"{MONITORS_PROGRAMMATIC_BASE_URL}/get_model_health"
+BULK_CHUNK_SIZE = 2000
